@@ -6,8 +6,8 @@
 #' @return List of elements
 #' @export
 #' @examples
-#' if (have_gifti_test_data()) {
-#'    gii_files = download_gifti_data()
+#' if (have_gifti_test_data(outdir = NULL)) {
+#'    gii_files = download_gifti_data(outdir = NULL)
 #'    L = gifti_list(gii_files[1])
 #'    orig = L$DataArray$Data[[1]]
 #'    encoding = attributes(L$DataArray)$Encoding
@@ -20,6 +20,10 @@
 #'    enc == orig
 #' }
 gifti_list = function(file) {
+  ######################
+  # Allow to read gii.gz
+  ######################
+  file = decompress_gii(file)
   doc = read_xml(file)
   doc = as_list(doc)
   class(doc) = "gifti_list"
